import Qmail

test1 = Qmail.SMTP(\
    EMAIL='yourmail@yourdomain.com', # Default: emailsender437@gmail.com

    PASSWORD= 'Your App Password', # Default: emailsender437 pass
    
    smtp= "smtp.domain.com", # Ex: smtp.gmail.com, Default : smtp.gmail.com

    reciever_emails= ["Mail To send1", "Mail To Send2", 'exc.'],  # Emails that will be recieving mails.

    port='port to send email in', # Optional

    cc='cc email address', # Give this value if cc needed in email

    bcc= 'bcc email address', # Give this value if bcc needed in email
    )  

sender = Qmail.SMTP(reciever_emails= ['email1@gmail.com']) # Create a default Qmail smtp server 

sender2 = Qmail.SMTP(\
    EMAIL='Your Mail Goes Here', 
    PASSWORD= "Your EMAIL'S app password goes here.", 
    reciever_emails=['receicermail@yourdomain.com'], 
    smtp= 'Your Emails Smtp Server'

) # Create a Qmail smtp server with your email. 


# Qmail MSG class is for PLAIN Emails

message = Qmail.MSG(\
    subject= 'Subject Of Email',
    txt= 'txt in the email',
   #attachments=['file1', 'file2'] # Add Attachment Filepaths here 

    )

message = Qmail.HTML_MSG(\
    subject= 'Subject Of Email',
    html= '<h1>Enter Html Here</h1>',
    #attachments=['file1', 'file2'] # Add Attachment Filepaths here 

    )


from Qmail import OTP

one_time_password = OTP.generateOTP(lenght=10, type='alphanumeric')
NAME = 'Qmail'

themes_available = ['simple', 'default', 'modern']


message = OTP.OTP_EMAIL(subject='OTP MAIl', otp=one_time_password, brand_name=NAME, theme='default')


import ssl
import smtplib
import time
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from email import encoders
from email.mime.base import MIMEBase
import random
import math

class NoOtpGivenError(Exception):
    """Exception raised when no otp is given.

    Attributes:
        otp -- the value that was not given
        message -- explanation of the error
    """

    def __init__(self, otp, message="No otp was given when creating an OTP_EMAIL class."):
        self.otp = otp
        self.message = message
        super().__init__(self.message)

class OTP_EMAIL:
    def __init__(self,subject = 'Otp Email', brand_name = 'title', otp = None, theme = 'default'):
        self.creator = 'Akmal Riyas'
        
        if otp == None:
            raise NoOtpGivenError(otp)
        
        self.text = MIMEMultipart("alternative")
        self.text["Subject"] = subject

        if theme == 'default':
            self.text.attach(MIMEText(self.default_theme(otp=otp, brand=brand_name), "html"))
        
        if theme == 'simple':
            self.text.attach(MIMEText(self.simple_theme(otp=otp, brand=brand_name), "html"))
        
        if theme == 'modern':
            self.text.attach(MIMEText(self.modern(otp=otp, brand=brand_name), "html"))
    

    def default_theme(self, otp, brand):
        theme = f"""
        <div style="font-family: Helvetica,Arial,sans-serif;min-width:1000px;overflow:auto;line-height:2">
            <div style="margin:50px auto;width:70%;padding:20px 0">
                <div style="border-bottom:1px solid #eee">
                    <a href="" style="font-size:1.4em;color: #00466a;text-decoration:none;font-weight:600">{brand}</a>
                </div>
                    <p style="font-size:1.1em">Hi,</p>
                    <p>Thank you for choosing {brand}. Use the following OTP to complete your procedures. OTP is valid for 2 minutes</p>
                    <h2 style="background: #00466a;margin: 0 auto;width: max-content;padding: 0 10px;color: #fff;border-radius: 4px;">{otp}</h2>
                    <p style="font-size:0.9em;">Regards,<br />{brand}</p>
                    <hr style="border:none;border-top:1px solid #eee" />
                <div style="float:right;padding:8px 0;color:#aaa;font-size:0.8em;line-height:1;font-weight:300">
                    <p>{brand}</p>
                    <p>created by easymail</p>
                    
                </div>
            </div>
        </div>"""

        return theme
    
    def simple_theme(self, otp, brand):
        theme = """<!doctype html>
        <html xmlns="http://www.w3.org/1999/xhtml" xmlns:v="urn:schemas-microsoft-com:vml" xmlns:o="urn:schemas-microsoft-com:office:office">

        <head>
        <title>
        </title>
        <!--[if !mso]><!-->
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <!--<![endif]-->
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <style type="text/css">
            #outlook a (
            padding: 0;
            )

            body (
            margin: 0;
            padding: 0;
            -webkit-text-size-adjust: 100%;
            -ms-text-size-adjust: 100%;
            )

            table,
            td (
            border-collapse: collapse;
            mso-table-lspace: 0pt;
            mso-table-rspace: 0pt;
            )

            img (
            border: 0;
            height: auto;
            line-height: 100%;
            outline: none;
            text-decoration: none;
            -ms-interpolation-mode: bicubic;
            )

            p (
            display: block;
            margin: 13px 0;
            )
        </style>
        <!--[if mso]>
                <noscript>
                <xml>
                <o:OfficeDocumentSettings>
                <o:AllowPNG/>
                <o:PixelsPerInch>96</o:PixelsPerInch>
                </o:OfficeDocumentSettings>
                </xml>
                </noscript>
                <![endif]-->
        <!--[if lte mso 11]>
                <style type="text/css">
                .mj-outlook-group-fix ( width:100% !important; )
                </style>
                <![endif]-->
        <!--[if !mso]><!-->
        <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,400,500,700" rel="stylesheet" type="text/css">
        <style type="text/css">
            @import url(https://fonts.googleapis.com/css?family=Open+Sans:300,400,500,700);
        </style>
        <!--<![endif]-->
        <style type="text/css">
            @media only screen and (min-width:480px) ()
            .mj-column-per-100 ()
                width: 100% !important;
                max-width: 100%;
            )
            )
        </style>
        <style media="screen and (min-width:480px)">
            .moz-text-html .mj-column-per-100 (
            width: 100% !important;
            max-width: 100%;
            )
        </style>
        <style type="text/css">
        </style>
        </head>

        <body style="word-spacing:normal;background-color:#fafbfc;">
        <div style="background-color:#fafbfc;">
            <!--[if mso | IE]><table align="center" border="0" cellpadding="0" cellspacing="0" class="" style="width:600px;" width="600" ><tr><td style="line-height:0px;font-size:0px;mso-line-height-rule:exactly;"><![endif]-->
            <div style="margin:0px auto;max-width:600px;">
            <table align="center" border="0" cellpadding="0" cellspacing="0" role="presentation" style="width:100%;">
                <tbody>
                <tr>
                    <td style="direction:ltr;font-size:0px;padding:20px 0;padding-bottom:20px;padding-top:20px;text-align:center;">
                    <!--[if mso | IE]><table role="presentation" border="0" cellpadding="0" cellspacing="0"><tr><td class="" style="vertical-align:middle;width:600px;" ><![endif]-->
                    <div class="mj-column-per-100 mj-outlook-group-fix" style="font-size:0px;text-align:left;direction:ltr;display:inline-block;vertical-align:middle;width:100%;">
                        <table border="0" cellpadding="0" cellspacing="0" role="presentation" style="vertical-align:middle;" width="100%">
                        <tbody>
                            <tr>
                            <td align="center" style="font-size:0px;padding:25px;word-break:break-word;">
                                <div style="font-family:open Sans Helvetica, Arial, sans-serif;font-size:30px;font-style:normal;line-height:1;text-align:center;color:#000000;">{Brand}</div>
                            </td>
                            </tr>
                        </tbody>
                        </table>
                    </div>
                    <!--[if mso | IE]></td></tr></table><![endif]-->
                    </td>
                </tr>
                </tbody>
            </table>
            </div>
            <!--[if mso | IE]></td></tr></table><table align="center" border="0" cellpadding="0" cellspacing="0" class="" style="width:600px;" width="600" bgcolor="#ffffff" ><tr><td style="line-height:0px;font-size:0px;mso-line-height-rule:exactly;"><![endif]-->
            <div style="background:#ffffff;background-color:#ffffff;margin:0px auto;max-width:600px;">
            <table align="center" border="0" cellpadding="0" cellspacing="0" role="presentation" style="background:#ffffff;background-color:#ffffff;width:100%;">
                <tbody>
                <tr>
                    <td style="direction:ltr;font-size:0px;padding:20px 0;padding-bottom:20px;padding-top:20px;text-align:center;">
                    <!--[if mso | IE]><table role="presentation" border="0" cellpadding="0" cellspacing="0"><tr><td class="" style="vertical-align:middle;width:600px;" ><![endif]-->
                    <div class="mj-column-per-100 mj-outlook-group-fix" style="font-size:0px;text-align:left;direction:ltr;display:inline-block;vertical-align:middle;width:100%;">
                        <table border="0" cellpadding="0" cellspacing="0" role="presentation" style="vertical-align:middle;" width="100%">
                        <tbody>
                            <tr>
                            <td align="center" style="font-size:0px;padding:10px 25px;padding-right:25px;padding-left:25px;word-break:break-word;">
                                <div style="font-family:open Sans Helvetica, Arial, sans-serif;font-size:16px;line-height:1;text-align:center;color:#000000;"><span>Hello,</span></div>
                            </td>
                            </tr>
                            <tr>
                            <td align="center" style="font-size:0px;padding:10px 25px;padding-right:25px;padding-left:25px;word-break:break-word;">
                                <div style="font-family:open Sans Helvetica, Arial, sans-serif;font-size:16px;line-height:1;text-align:center;color:#000000;">Heres your one time password:</div>
                            </td>
                            </tr>
                            <tr>
                            <td align="center" style="font-size:0px;padding:10px 25px;word-break:break-word;">
                                <div style="font-family:open Sans Helvetica, Arial, sans-serif;font-size:24px;font-weight:bold;line-height:1;text-align:center;color:#000000;">{OTP}</div>
                            </td>
                            </tr>
                            <tr>
                            <td align="center" style="font-size:0px;padding:10px 25px;padding-right:16px;padding-left:25px;word-break:break-word;">
                                <div style="font-family:open Sans Helvetica, Arial, sans-serif;font-size:16px;line-height:1;text-align:center;color:#000000;">If you didn't request this, you can ignore this email or let us know.</div>
                            </td>
                            </tr>
                            <tr>
                            <td align="center" style="font-size:0px;padding:10px 25px;padding-right:25px;padding-left:25px;word-break:break-word;">
                                <div style="font-family:open Sans Helvetica, Arial, sans-serif;font-size:16px;line-height:1;text-align:center;color:#000000;">Thanks! <br />{Brand} team</div>
                            </td>
                            </tr>
                        </tbody>
                        </table>
                    </div>
                    <!--[if mso | IE]></td></tr></table><![endif]-->
                    </td>
                </tr>
                </tbody>
            </table>
            </div>
            <!--[if mso | IE]></td></tr></table><![endif]-->
        </div>
        </body>

        </html>
        """.format(Brand= brand, OTP = otp)

        return theme
    
    def modern(self, otp, brand):
        theme = """
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>OTP</title>
  <!--[if mso]><style type="text/css">body, table, td, a ( font-family: Arial, Helvetica, sans-serif !important; )</style><![endif]-->
</head>

<body style="font-family: Helvetica, Arial, sans-serif; margin: 0px; padding: 0px; background-color: #ffffff;">
  <table role="presentation"
    style="width: 100%; border-collapse: collapse; border: 0px; border-spacing: 0px; font-family: Arial, Helvetica, sans-serif; background-color: rgb(239, 239, 239);">
    <tbody>
      <tr>
        <td align="center" style="padding: 1rem 2rem; vertical-align: top; width: 100%;">
          <table role="presentation" style="max-width: 600px; border-collapse: collapse; border: 0px; border-spacing: 0px; text-align: left;">
            <tbody>
              <tr>
                <td style="padding: 40px 0px 0px;">
                  <div style="text-align: left;">
                    <div style="padding-bottom: 20px;">
                        <h1>
                            {Brand}
                        </h1>
                    </div>
                  </div>
                  <div style="padding: 20px; background-color: rgb(255, 255, 255);">
                    <div style="color: rgb(0, 0, 0); text-align: left;">
                      <h1 style="margin: 1rem 0">Verification code</h1>
                      <p style="padding-bottom: 16px">Please use the OTP below</p>
                      <p style="padding-bottom: 16px"><strong style="font-size: 130%">{OTP}</strong></p>
                      <p style="padding-bottom: 16px">If you didn’t request this, you can ignore this email.</p>
                      <p style="padding-bottom: 16px">Thanks,<br>The {Brand} team</p>
                    </div>
                  </div>
                  <div style="padding-top: 20px; color: rgb(153, 153, 153); text-align: center;">
                    <p style="padding-bottom: 16px">Made by {Brand} using easymail</p>
                  </div>
                </td>
              </tr>
            </tbody>
          </table>
        </td>
      </tr>
    </tbody>
  </table>
</body>

</html>

""".format(Brand = brand, OTP= otp)

        return theme



def generateOTP(lenght=4, type = 'numeric') :
        if lenght < 4:
            print('Atleast 4 characters is recommended for an OTP')

        if type == 'numeric':
            digits = "0123456789"
            OTP = ""

            for i in range(lenght) :
                OTP += digits[math.floor(random.random() * 10)]
    
            return OTP
        
        elif type == 'alphanumeric':
            string = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
            OTP = ""
            length = len(string)
            for i in range(lenght) :
                OTP += string[math.floor(random.random() * length)]
        
            return OTP


import ssl
import smtplib
import time
from email.mime.text import MIMEText
from email.mime.multipart import MIMEMultipart
from email import encoders
from email.mime.base import MIMEBase
import math
import random

# default acc

default_acc_pass = 'zsewpnjiocuigwgi'
default_acc_email = 'emailsender437@gmail.com'


class SMTP:
    def __init__(self, EMAIL = default_acc_email, PASSWORD = default_acc_pass, port = 465, reciever_emails = [], smtp = 'smtp.gmail.com', cc = None, bcc = None):
        self.creator = 'Akmal Riyas'

        self.email = EMAIL
        self.password = PASSWORD
        self.to_send = reciever_emails

        self.domain = smtp
        

        self.context = ssl.create_default_context()
        self.port = port

        self.cc = cc
        self.bcc = bcc

    ### SEND TYPES ###
    
    def send_mail(self, message):
        message = self.add_msg_headers(message)
        

        if self.to_send != []:
            for email in self.to_send:
                self.send(reciever_mail=email, data= message.text)
    

    ### SEND ###
    
    def send(self, reciever_mail, data, type = 't'):
        
        try:

            with smtplib.SMTP_SSL(self.domain, self.port, context=self.context) as server:
                server.login(self.email, self.password)
                
                server.sendmail(self.email, reciever_mail, data.as_string())
            
            print(f'Mail Sent to {reciever_mail} \n')
        
        except Exception as e:
            print(e)


    ### SPAM ###
    def spam_mail(self, message,  num = 5):
        message = self.add_msg_headers(message)
        for num in range(0, num):
            print(num +1)
            for mail in self.to_send:
                self.send(reciever_mail= mail, data=message.text)
            
            
            time.sleep(1)

    
    def add_msg_headers(self,msg):
        msg.text['From'] = self.email
        msg.text['To'] = self.to_send[0]

        if self.cc != None:
            msg.text['CC'] = self.cc
            self.to_send.append(self.cc)
        
        elif self.bcc != None:
            self.to_send.append(self.bcc)

        
        return msg




class MSG:
    def __init__(self, subject = 'msg', txt= 'hi', attachments = []):
        self.text = MIMEMultipart("alternative")
        self.text["Subject"] = subject
        self.text.attach(MIMEText(txt, "plain"))

        if attachments != [] or attachments != '':
            files = FILES(attachments)
            
            for file in files.parts:
                self.text.attach(file)



    def print_message(self):
        print(self.text.as_string())

class FILES:
    def __init__(self, files):
        self.parts = []

        if type(files) == str:
           self.parts.append(self.create_part(files))
    
        elif type(files) == list:

            for file in files:
                self.parts.append(self.create_part(file))
                

    def create_part(self,file):
        with open(file, "rb") as attachment:              
            part = MIMEBase("application", "octet-stream")
            part.set_payload(attachment.read())

            encoders.encode_base64(part)

            part.add_header(
                "Content-Disposition",
                f"attachment; filename= {file}",
            )
        
        return part

class HTML_MSG:
    def __init__(self, subject = 'html msg', txt = '', html= '<h1> HI </h1>', attachments = []):
        self.text = MIMEMultipart("alternative")
        self.text["Subject"] = subject

        if txt != '':
            self.text.attach(MIMEText(txt, "plain"))
            self.text.attach(MIMEText(html, "html"))
            
        
        else:
            self.text.attach(MIMEText(html, 'html'))
        
        if attachments != [] or attachments != '':
            files = FILES(attachments)
            
            for file in files.parts:
                self.text.attach(file)
        
        
        
        

    def print_message(self):
        print(self.text.as_string())




from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    LONG_DESCRIPTION = "\n" + fh.read()

VERSION = '0.0.1'
DESCRIPTION = 'Sending Mails Made Easy'


# Setting up
setup(
    name="Qmail",
    version=VERSION,
    author="Akmal Riyas",
    author_email="akmalriyas@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages= ["Qmail"],
   
    keywords=['python', 'mail', 'email', 'easymail','gmail','send_mail', 'otp', 'passwordgen'],
    dependency_links=[
        'https://github.com/Akmal-Riyas/Qmail/tree/mains'
    ],

)